#
# spec file for package python-check-manifest
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-check-manifest%{psuffix}
Version:        0.50
Release:        1.2
Summary:        Tool to check Python source package MANIFEST.in for completeness
License:        MIT
URL:            https://github.com/mgedmin/check-manifest
Source:         https://files.pythonhosted.org/packages/source/c/check_manifest/check_manifest-%{version}.tar.gz
Patch0:         use-current-interpreter.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-build >= 0.1
Requires:       python-setuptools
%if 0%{?python_version_nodots} < 311
Requires:       python-tomli
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     git-core > 2.11
Recommends:     python-pip
Recommends:     python-wheel
Suggests:       breezy
Suggests:       mercurial
Suggests:       subversion
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module check-manifest = %{version}}
BuildRequires:  %{python_module pytest}
BuildRequires:  breezy
BuildRequires:  git-core > 2.11
BuildRequires:  mercurial
BuildRequires:  subversion
%endif
%python_subpackages

%description
check-manifest is a tool for python developers to check for broken packages
and missing files in MANIFEST.

%prep
%setup -q -n check_manifest-%{version}
%if 0%{?suse_version} == 1500
%patch -P 0 -p1
%endif
sed -i '1{\,^#!%{_bindir}/env python,d}' check_manifest.py
chmod -x check_manifest.py

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/check-manifest
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
export LANG=en_US.UTF-8
# uses pip which likes to use internet to resolve versions
skip='test_build_sdist'
# Fix tests https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1023597
git config --global --add protocol.file.allow always
%pytest -rs -k "not ($skip)"
%endif

%if !%{with test}
%post
%python_install_alternative check-manifest

%postun
%python_uninstall_alternative check-manifest

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE.rst
%python_alternative %{_bindir}/check-manifest
%{python_sitelib}/check_manifest.py
%pycache_only %{python_sitelib}/__pycache__/check_manifest*.pyc
%{python_sitelib}/check_manifest-%{version}.dist-info
%endif

%changelog
* Wed Dec 11 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.50
  * Add Python 3.12 and 3.13 support.
- Adjust upstream source name in spec file
* Wed Feb 28 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to breezy everywhere.
- Use %%patch macro.
* Fri Dec  1 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to use the current interpreter by default in the
  TestCheckManifest::test_python_from_path test in SLE. Otherwise
  the test runs the python3.6 interpreter which doesn't work:
  * use-current-interpreter.patch
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sat May 20 2023 Ben Greiner <code@bnavigator.de>
- Do not require bzr (breezy) for tests: fails in Factory, we're
  the only user
- PEP517
- Fix tomli runtime requirement
* Mon Apr  3 2023 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded {Build,}Requires on pep517.
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.49:
  * Add Python 3.11 support.
  * Drop Python 3.6 support.
- drop python-check-manifest-no-mock.patch (upstream)
* Thu Nov 24 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add "git config --global --add protocol.file.allow always" to fix tests,
  based on https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1023597
* Mon Sep 26 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 0.48
  Add Python 3.10 support.
  Switch to tomli instead of toml, after hearing about PEP-680. tomli will be included in the Python 3.11 standard library as
  tomllib, while toml is apparently unmaintained.
  Fix submodule support when .gitmodules exists in a subdirectory (#153). Note that this reverts a fix for #124: git versions
  before 2.11 are no longer supported.
* Thu Mar 10 2022 Matej Cepl <mcepl@suse.com>
- Add python-check-manifest-no-mock.patch
  (gh#mgedmin/check-manifest#151) replace using mock with
  unittest.mock.
* Wed Mar  9 2022 pgajdos@suse.com
- version update to 0.47
  0.47 (2021-09-22)
  - ----------------
  - Fix ``setuptools_scm`` workaround for packages with dashes in the name
    (`#145 <https://github.com/mgedmin/check-manifest/issues/145>`_).
  0.46 (2021-01-04)
  - ----------------
  - The `pre-commit <https://pre-commit.com>`__ hook now always uses Python 3.
* Tue Nov 24 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.45
  * Add Python 3.9 support.
  * Drop Python 3.5 support.
  * Switch from pep517 to python-build
  * Add ``--no-build-isolation`` option so check-manifest can
    succeed building pep517-based distributions without an
    internet connection.
    With --no-build-isolation, you must preinstall the
    ``build-system.requires`` beforehand.
- from v0.44
  * Try to avoid passing ``--recurse-submodules`` to ``git ls``
    if the project doesn't use git submodules (i.e. doesn't
    have a ``.gitsubmodules`` file)
    This should make check-manifest work again with older git
    versions, as long as you don't use submodules
- from v0.43
  * Fix collecting files versioned by ``git`` when a project
    has submodules and ``GIT_INDEX_FILE`` is set. This bug was
    triggered when ``check-manifest`` was run from a git hook
* Thu Aug 20 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.42
  * Added ``-q``/``--quiet`` command line argument. This will reduce the
    verbosity of informational output, e.g. for use in a CI pipeline.
  * Rewrote the ignore logic to be more compatible with setuptools.  This
    might have introduced some regressions, so please file bugs!  One side
    effect of this is that ``--ignore`` (or the ``ignore`` setting in the
    config file) is now handled the same way as ``global-exclude`` in a
    ``MANIFEST.in``, which means:
  - it's matched anywhere in the file tree
  - it's ignored if it matches a directory
  * Drop Python 2.7 support.
- from v0.41
  * Support `PEP 517`_, i.e. packages using pyproject.toml
  * Ignore subcommand stderr unless the subcommand fails.
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri May  1 2020 Matej Cepl <mcepl@suse.com>
- Switch to multibuild and remove Suggests for bzr.
* Wed Apr  8 2020 Matej Cepl <mcepl@suse.com>
- Don't build-require bzr, just suggest it, it is not that necessary.
- Switch tests to using pytest as a test runner.
* Wed Oct 23 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.40
  * Add Python 3.8 support.
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.39:
  * You can now use check-manifest as a pre-commit hook (#100).
  * Make tests pass on a system with no Python 2 and systems
    where the python interpreter is not called python but python3
    (gh#mgedmin/check-manifest#101, gh#mgedmin/check-manifest#57,
    bsc#1198295).
* Wed May 15 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Wed May  8 2019 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary bcond test
- Add optional VCS dependencies to BuildDepends and Suggests
- Use fdupes
- Revise Summary replacing confusing 'MANIFEST in' with MANIFEST.in
- Update to v0.38
  * Add Python 3.7 support
  * Drop Python 3.4 support.
  * Added GitHub templates to default ignore patterns
  * Added reading check-manifest config out of tox.ini or pyproject.toml
* Wed Sep 19 2018 Antonio Larrosa <alarrosa@suse.com> - 0.37
- update to version 0.37:
  * Drop Python 3.3 support.
  * Support packages using setuptools_scm (#68).
  * Note that setuptools_scm usually makes MANIFEST.in files obsolete.
    Having one is helpful only if you intend to build an sdist and then
    use that sdist to perform further builds, instead of building from
    a source checkout.
* Wed Nov 22 2017 arun@gmx.de
- update to version 0.36:
  * Handle empty VCS repositories more gracefully (#84).
* Thu Jul 13 2017 toddrme2178@gmail.com
- Initial version
